@@ -22,7 +22,14 @@ int pList::getList(std::vector<Proc> &proc, bool all){
 
   std::string line;
   while(getline(buff, line)){
-    static const boost::regex exp(" *([0-9]+) +(.+) +([DRSTWXZ<NLsl+]+) +([0-9]+:[0-9]+) +(.*)");
+   // static const boost::regex exp(" *([0-9]+) +(.+) +([DRSTWXZ<NLsl+]+) +([0-9]+:[0-9]+) +(.*)");
+   /*
+ 21994 ?        Sl     7:54 /usr/bin/amarok
+ 32003 ?        Ss     1:12 /usr/bin/wineserver
+ 32007 ?        Sl     0:00 C:\windows\system32\services.exe                                      
+
+   */
+	static const boost::regex exp("^ ([0-9]+) *(.*) *([0-9]+) *.+ *(.+)$");
     boost::match_results<std::string::const_iterator> results;
     if(!boost::regex_match(line, results, exp))
         continue;
